==> danse-2.2.11.tar.gz: danse/modules/config/src/Payload.php <==
<?php

namespace Drupal\danse_config;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\node\Entity\Node;
use Drupal\danse\Entity\EventInterface;
use Drupal\danse\PayloadBase;
use Drupal\danse\PayloadInterface;

/**
 * The config payload class.
 *
 * @package Drupal\danse_config
 */
final class Payload extends PayloadBase {

  /**
   * The config object.
   *
   * @var mixed
   */
  protected $object;

  /**
   * Config payload constructor.
   *
   * @param mixed $object
   *   The config object.
   */
  public function __construct($object = NULL) {
    $this->object = $object;
  }

  /**
   * {@inheritdoc}
   */
  public function label(EventInterface $event): string {
    return 'config';
  }

  /**
   * {@inheritdoc}
   */
  public function getEventReference(): string {
    return '';
  }

  /**
   * {@inheritdoc}
   */
  public function getSubscriptionReferences(EventInterface $event): array {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function prepareArray(): array {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public static function createFromArray(array $payload): ?PayloadInterface {
    return new Payload();
  }

  /**
   * {@inheritdoc}
   */
  public function getEntity(): ContentEntityInterface {
    /**
     * @var \Drupal\node\NodeInterface $entity
     */
    $entity = Node::create([
      'title' => 'not yet implemented',
    ]);
    return $entity;
  }

  /**
   * {@inheritdoc}
   */
  public function hasAccess(int $uid): bool {
    return FALSE;
  }

}

==> danse-2.2.14.tar.gz: danse/modules/config/src/Payload.php <==
<?php

namespace Drupal\danse_config;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\danse\Entity\Event;
use Drupal\danse\Entity\EventInterface;
use Drupal\danse\PayloadBase;
use Drupal\danse\PayloadInterface;

/**
 * The config payload class.
 *
 * @package Drupal\danse_config
 */
final class Payload extends PayloadBase {

  /**
   * The config object.
   *
   * @var mixed
   */
  protected $object;

  /**
   * Config payload constructor.
   *
   * @param mixed $object
   *   The config object.
   */
  public function __construct($object = NULL) {
    $this->object = $object;
  }

  /**
   * {@inheritdoc}
   */
  public function label(EventInterface $event): string {
    return 'config';
  }

  /**
   * {@inheritdoc}
   */
  public function getEventReference(): string {
    return '';
  }

  /**
   * {@inheritdoc}
   */
  public function getSubscriptionReferences(EventInterface $event): array {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function prepareArray(): array {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public static function createFromArray(array $payload): ?PayloadInterface {
    return new Payload();
  }

  /**
   * {@inheritdoc}
   */
  public function getEntity(): ContentEntityInterface {
    /**
     * @var \Drupal\danse\Entity\Event $entity
     */
    $entity = Event::create([
      'id' => 0,
      'plugin' => 'config',
      'topic' => '',
      'label' => '',
      'payload' => $this,
      'push' => TRUE,
      'force' => TRUE,
      'silent' => FALSE,
    ]);
    return $entity;
  }

  /**
   * {@inheritdoc}
   */
  public function hasAccess(int $uid): bool {
    return FALSE;
  }

}
